# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.ai_assistant_goal_get import AiAssistantGoalGet

class TestAiAssistantGoalGet(unittest.TestCase):
    """AiAssistantGoalGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantGoalGet:
        """Test AiAssistantGoalGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantGoalGet`
        """
        model = AiAssistantGoalGet()
        if include_optional:
            return AiAssistantGoalGet(
                additional_prompt = '',
                ai_assistant_id = 56,
                course_ids = [
                    56
                    ],
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                engagement_preset = chat_server_connector_v2.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                    created_at = 56, 
                    engagement = 56, 
                    engagement_opt_out_duration = 56, 
                    id = 56, 
                    max_engagement_count = 56, 
                    max_engagement_period = 56, 
                    max_total_engagement_count = 56, 
                    name = '', 
                    order = 56, ),
                engagement_preset_id = 56,
                id = 56,
                interactions_summary = chat_server_connector_v2.models.goal_interactions_summary.GoalInteractionsSummary(
                    is_available = True, 
                    last_engagement_at = 56, 
                    last_opt_out_at = 56, 
                    recent_interaction_count = 56, 
                    total_interaction_count = 56, ),
                is_active = True,
                is_fullfilled = True,
                last_updated_at = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                page_url = '',
                primary_course = chat_server_connector_v2.models.course_public.CoursePublic(
                    description = '', 
                    id = 56, 
                    modules = [
                        chat_server_connector_v2.models.course_module_public.CourseModulePublic(
                            id = 56, 
                            lessons = [
                                chat_server_connector_v2.models.module_lesson_public.ModuleLessonPublic(
                                    id = 56, 
                                    title = '', )
                                ], 
                            public_description = '', 
                            short_description = '', 
                            title = '', )
                        ], 
                    payment_type = 'paid', 
                    title = '', 
                    url = '', ),
                primary_course_id = 56
            )
        else:
            return AiAssistantGoalGet(
                additional_prompt = '',
                ai_assistant_id = 56,
                course_ids = [
                    56
                    ],
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                is_active = True,
                last_updated_at = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
        )
        """

    def testAiAssistantGoalGet(self):
        """Test AiAssistantGoalGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
