# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.response_wrapper_chat_settings_get import ResponseWrapperChatSettingsGet

class TestResponseWrapperChatSettingsGet(unittest.TestCase):
    """ResponseWrapperChatSettingsGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatSettingsGet:
        """Test ResponseWrapperChatSettingsGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatSettingsGet`
        """
        model = ResponseWrapperChatSettingsGet()
        if include_optional:
            return ResponseWrapperChatSettingsGet(
                done = True,
                result = chat_server_connector_v2.models.chat_settings_get.ChatSettingsGet(
                    chat_enabled = True, 
                    dms_enables = True, ),
                error = ''
            )
        else:
            return ResponseWrapperChatSettingsGet(
                done = True,
        )
        """

    def testResponseWrapperChatSettingsGet(self):
        """Test ResponseWrapperChatSettingsGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
