# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from chat_server_connector_v2.models.chat_get_with_members import ChatGetWithMembers
from chat_server_connector_v2.models.chat_message_read import ChatMessageRead
from chat_server_connector_v2.models.chat_session_type import ChatSessionType
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatSessionGetWithChatData(BaseModel):
    """
    ChatSessionGetWithChatData
    """ # noqa: E501
    id: StrictInt
    chat_id: StrictInt
    creator_id: StrictInt
    credentials: Dict[str, Any]
    chat_session_type: ChatSessionType
    created_at: StrictInt
    ended_at: Optional[StrictInt] = None
    last_activity_at: StrictInt
    messages: Optional[List[ChatMessageRead]] = None
    chat: ChatGetWithMembers
    tokens_used: Optional[Union[StrictFloat, StrictInt]] = 0.0
    __properties: ClassVar[List[str]] = ["id", "chat_id", "creator_id", "credentials", "chat_session_type", "created_at", "ended_at", "last_activity_at", "messages", "chat", "tokens_used"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatSessionGetWithChatData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item_messages in self.messages:
                if _item_messages:
                    _items.append(_item_messages.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of chat
        if self.chat:
            _dict['chat'] = self.chat.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatSessionGetWithChatData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "creator_id": obj.get("creator_id"),
            "credentials": obj.get("credentials"),
            "chat_session_type": obj.get("chat_session_type"),
            "created_at": obj.get("created_at"),
            "ended_at": obj.get("ended_at"),
            "last_activity_at": obj.get("last_activity_at"),
            "messages": [ChatMessageRead.from_dict(_item) for _item in obj["messages"]] if obj.get("messages") is not None else None,
            "chat": ChatGetWithMembers.from_dict(obj["chat"]) if obj.get("chat") is not None else None,
            "tokens_used": obj.get("tokens_used") if obj.get("tokens_used") is not None else 0.0
        })
        return _obj


