# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.chat_member_get import ChatMemberGet
from chat_server_connector_v2.models.chat_message import ChatMessage
from chat_server_connector_v2.models.chat_type import ChatType
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatListGet(BaseModel):
    """
    ChatListGet
    """ # noqa: E501
    id: StrictInt
    uuid: StrictStr
    chat_type: ChatType
    avatar_id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    messaging_enabled: StrictBool
    permalink_enabled: StrictBool
    is_visible: StrictBool
    topic_slug: Optional[StrictStr] = None
    is_muted: Optional[StrictBool] = False
    created_at: StrictInt
    last_updated_at: StrictInt
    members: Optional[List[ChatMemberGet]] = None
    last_message: Optional[ChatMessage] = None
    unread_count: Optional[StrictInt] = 0
    __properties: ClassVar[List[str]] = ["id", "uuid", "chat_type", "avatar_id", "name", "description", "messaging_enabled", "permalink_enabled", "is_visible", "topic_slug", "is_muted", "created_at", "last_updated_at", "members", "last_message", "unread_count"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatListGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item_members in self.members:
                if _item_members:
                    _items.append(_item_members.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of last_message
        if self.last_message:
            _dict['last_message'] = self.last_message.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatListGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "uuid": obj.get("uuid"),
            "chat_type": obj.get("chat_type"),
            "avatar_id": obj.get("avatar_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "messaging_enabled": obj.get("messaging_enabled"),
            "permalink_enabled": obj.get("permalink_enabled"),
            "is_visible": obj.get("is_visible"),
            "topic_slug": obj.get("topic_slug"),
            "is_muted": obj.get("is_muted") if obj.get("is_muted") is not None else False,
            "created_at": obj.get("created_at"),
            "last_updated_at": obj.get("last_updated_at"),
            "members": [ChatMemberGet.from_dict(_item) for _item in obj["members"]] if obj.get("members") is not None else None,
            "last_message": ChatMessage.from_dict(obj["last_message"]) if obj.get("last_message") is not None else None,
            "unread_count": obj.get("unread_count") if obj.get("unread_count") is not None else 0
        })
        return _obj


